==> cloud-5.1.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/entity/entity_info_tab.ts <==
import OPENSTACK_HEAT_EVENT_TEMPLATE from 'constant/templates/entity/openstack/heat_event';
import OPENSTACK_HEAT_RESOURCE_TEMPLATE from 'constant/templates/entity/openstack/heat_resource';
import EntityInfoTabTemplate from 'model/EntityInfoTabTemplate';

const ENTITY_INFO_TAB_LIST: EntityInfoTabTemplate[] = [
  {
    cloudServiceProvider: 'openstack',
    entityName: 'instance',
    tabs: [
      { name: 'edit', labelName: 'Edit', columns: [] },
      { name: 'console_output', labelName: 'Console output', columns: [] },
      { name: 'delete', labelName: 'Delete', columns: [] },
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'image',
    tabs: [
      { name: 'edit', labelName: 'Edit', columns: [] },
      { name: 'delete', labelName: 'Delete', columns: [] },
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'stack',
    tabs: [
      { name: 'resource', labelName: 'Resources', columns: [
        { name: 'name', labelName: 'Name', type: 'default' },
        { name: 'resource_id', labelName: 'Resource ID', type: 'default' },
        { name: 'resource_type', labelName: 'Resource Type', type: 'default' },
        { name: 'changed', labelName: 'Date Updated', type: 'datetime' },
        { name: 'resource_status', labelName: 'Status', type: 'default' },
        { name: 'resource_status_reason', labelName: 'Status Reason', type: 'default' },
      ], detail: OPENSTACK_HEAT_RESOURCE_TEMPLATE },
      { name: 'event', labelName: 'Events', columns: [
        { name: 'name', labelName: 'Name', type: 'default' },
        { name: 'resource_name', labelName: 'Stack Resource', type: 'default' },
        { name: 'resource_id', labelName: 'Resource', type: 'default' },
        { name: 'changed', labelName: 'Time Since Event', type: 'datetime' },
        { name: 'resource_status', labelName: 'Status', type: 'default' },
        { name: 'resource_status_reason', labelName: 'Status Reason', type: 'default' },
      ], detail: OPENSTACK_HEAT_EVENT_TEMPLATE },
    ]
  }
]

export default ENTITY_INFO_TAB_LIST;

==> cloud-5.5.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/entity/entity_info_tab.ts <==
import OPENSTACK_HEAT_EVENT_TEMPLATE from 'constant/templates/entity/openstack/heat_event';
import OPENSTACK_HEAT_RESOURCE_TEMPLATE from 'constant/templates/entity/openstack/heat_resource';
import EntityInfoTabTemplate from 'model/EntityInfoTabTemplate';

const ENTITY_INFO_TAB_LIST: EntityInfoTabTemplate[] = [
  {
    cloudServiceProvider: 'openstack',
    entityName: 'instance',
    tabs: [
      { name: 'edit', labelName: 'Edit', columns: [] },
      { name: 'console_output', labelName: 'Log', columns: [] },
      { name: 'console', labelName: 'Console', columns: [] },
      { name: 'action_log', labelName: 'Action log', columns: [] },
      { name: 'delete', labelName: 'Delete', columns: [] },
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'image',
    tabs: [
      { name: 'edit', labelName: 'Edit', columns: [] },
      { name: 'delete', labelName: 'Delete', columns: [] },
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'stack',
    tabs: [
      { name: 'resource', labelName: 'Resources', columns: [
        { name: 'name', labelName: 'Name', type: 'default' },
        { name: 'resource_id', labelName: 'Resource ID', type: 'default' },
        { name: 'resource_type', labelName: 'Resource Type', type: 'default' },
        { name: 'changed', labelName: 'Date Updated', type: 'datetime' },
        { name: 'resource_status', labelName: 'Status', type: 'default' },
        { name: 'resource_status_reason', labelName: 'Status Reason', type: 'default' },
      ], detail: OPENSTACK_HEAT_RESOURCE_TEMPLATE },
      { name: 'event', labelName: 'Events', columns: [
        { name: 'name', labelName: 'Name', type: 'default' },
        { name: 'resource_name', labelName: 'Stack Resource', type: 'default' },
        { name: 'resource_id', labelName: 'Resource', type: 'default' },
        { name: 'changed', labelName: 'Time Since Event', type: 'datetime' },
        { name: 'resource_status', labelName: 'Status', type: 'default' },
        { name: 'resource_status_reason', labelName: 'Status Reason', type: 'default' },
      ], detail: OPENSTACK_HEAT_EVENT_TEMPLATE },
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'server_group',
    tabs: [
      { name: 'delete', labelName: 'Delete', columns: [] },
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'cloud_launch_template',
    tabs: [
      { name: 'edit', labelName: 'Edit', columns: [] },
      { name: 'delete', labelName: 'Delete', columns: [] },
      { name: 'launch', labelName: 'Launch', columns: [] },
      { name: 'copy', labelName: 'Copy', columns: [] },
      { name: 'revisions', labelName: 'Revisions', columns: [] },
    ]
  },
]

export default ENTITY_INFO_TAB_LIST;
